package net.sourceforge.tedhi;

/**
 * Defines a hint for how to default date components when they are not supplied in the
 * input to a parser.
 * This bias can be applied to any date component except year.
 * 
 * Indicates bias to start or end of months/years etc.,
 * where supplied pattern is a partial date
 */
public enum Bias {
	/**
	 * Affected date components are defaulted to the <i>start</i> of their range,
	 * given the rest of the defined date.
	 * Usually this means setting the components value to {@code 0} or {@code 1},
	 * depending on its first allowed value.
	 */
	START,
	
	/**
	 * Affected date components are defaulted to the <i>end</i> of their range,
	 * given the rest of the defined date.
	 * For months this means the last month of the year; for days it's the last
	 * day of the month; for time-of-day it's the last instant of the day
	 * (accurate the smallest unit of the date type used).
	 */
	END
}