package net.sourceforge.tedhi;

/**
 * Defines a hint for how to default years when they are not supplied in the
 * input to a parser.
 * The year range bias is applied when neither date in a range are specified with a year.
 */
public enum YearBias {
	/**
	 * Choose year such that the resultant date is closest to the current date.
	 * The generated date may be before, after, or equal to the current
	 * date.
	 */
	NEAREST,
	
	/**
	 * Choose year such that the date is the closest to the current date
	 * while not being in the future. The generated date may be earlier than or
	 * equal to the current date.
	 */
	PAST,

	/**
	 * Use the current year, regardless of whether this generates
	 * a date in the past or the future.
	 */
	CURRENT,
	
	/**
	 * Choose year such that the date is the closest to the current date
	 * while not being in the past. The generated date may be after or
	 * equal to the current date.
	 */
	FUTURE,
}
